==> mx-packageinstaller-pkglist_19.01.01.tar.xz: mx-packageinstaller-pkglist/shotwell.pm <==
<?xml version="1.0"?>
<app>

<category>
Graphics
</category>

<name>
Shotwell
</name>

<description>
   <am>digital photo organizer</am>
   <ca>Organitzador de fotos digitals</ca>
   <cs>digital photo organizer</cs>
   <da>digital photo organizer</da>
   <de>Digitalfoto-Organizer</de>
   <el>ψηφιακό διοργανωτή φωτογραφιών</el>
   <en>digital photo organizer</en>
   <es>digital photo organizer</es>
   <fi>digital photo organizer</fi>
   <fr>Agenda photo numérique</fr>
   <hi>digital photo organizer</hi>
   <hr>digital photo organizer</hr>
   <hu>digital photo organizer</hu>
   <is>digital photo organizer</is>
   <it>organizzatore di foto digitali</it>
   <ja>digital photo organizer</ja>
   <kk>digital photo organizer</kk>
   <lt>digital photo organizer</lt>
   <nl>digitale foto-organisator</nl>
   <pl>digital photo organizer</pl>
   <pt_BR>digital photo organizer</pt_BR>
   <pt>digital photo organizer</pt>
   <ro>digital photo organizer</ro>
   <ru>Каталогизатор фотографий и видеофайлов</ru>
   <sk>digital photo organizer</sk>
   <sq>digital photo organizer</sq>
   <sv>digital foto-organiserare</sv>
   <tr>digital photo organizer</tr>
   <uk>digital photo organizer</uk>
   <zh_TW>digital photo organizer</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>https://screenshots.debian.net/screenshots/000/009/008/large.png</screenshot>

<preinstall>

</preinstall>

<install_package_names>
shotwell
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
shotwell
</uninstall_package_names>
</app>

==> mx-packageinstaller-pkglist_19.03.01.tar.xz: mx-packageinstaller-pkglist/shotwell.pm <==
<?xml version="1.0"?>
<app>

<category>
Graphics
</category>

<name>
Shotwell
</name>

<description>
   <am>digital photo organizer</am>
   <ar>digital photo organizer</ar>
   <bg>digital photo organizer</bg>
   <ca>Organitzador de fotos digitals</ca>
   <cs>digital photo organizer</cs>
   <da>organisering af digitale billeder</da>
   <de>Digitalfoto-Organizer</de>
   <el>ψηφιακό διοργανωτή φωτογραφιών</el>
   <en>digital photo organizer</en>
   <es>Organizador de fotografías digitales</es>
   <et>digital photo organizer</et>
   <eu>digital photo organizer</eu>
   <fa>digital photo organizer</fa>
   <fi>digital photo organizer</fi>
   <fr>Agenda photo numérique</fr>
   <he_IL>digital photo organizer</he_IL>
   <hi>digital photo organizer</hi>
   <hr>digital photo organizer</hr>
   <hu>digital photo organizer</hu>
   <id>digital photo organizer</id>
   <is>digital photo organizer</is>
   <it>organizzatore di foto digitali</it>
   <ja_JP>digital photo organizer</ja_JP>
   <ja>digital photo organizer</ja>
   <kk>digital photo organizer</kk>
   <ko>digital photo organizer</ko>
   <lt>digital photo organizer</lt>
   <mk>digital photo organizer</mk>
   <nb>digital photo organizer</nb>
   <nl>digitale foto-organisator</nl>
   <pl>digital photo organizer</pl>
   <pt_BR>digital photo organizer</pt_BR>
   <pt>digital photo organizer</pt>
   <ro>digital photo organizer</ro>
   <ru>Каталогизатор фотографий и видеофайлов</ru>
   <sk>digital photo organizer</sk>
   <sl>digital photo organizer</sl>
   <sq>digital photo organizer</sq>
   <sr>digital photo organizer</sr>
   <sv>digital foto-organiserare</sv>
   <tr>digital photo organizer</tr>
   <uk>digital photo organizer</uk>
   <zh_CN>digital photo organizer</zh_CN>
   <zh_TW>digital photo organizer</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>https://screenshots.debian.net/screenshots/000/009/008/large.png</screenshot>

<preinstall>

</preinstall>

<install_package_names>
shotwell
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
shotwell
</uninstall_package_names>
</app>
